@@ -4,8 +4,9 @@ use warnings;
 
 package MooseX::AttributeDocumented;
 
-our $VERSION = '0.1003'; # VERSION
 # ABSTRACT: Add Documented trait to all to attributes
+our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
+our $VERSION = '0.1004';
 
 use Moose;
 use Moose::Exporter;
@@ -26,9 +27,23 @@ __END__
 
 MooseX::AttributeDocumented - Add Documented trait to all to attributes
 
+
+
+=begin html
+
+<p>
+<img src="https://img.shields.io/badge/perl-5.10.1+-blue.svg" alt="Requires Perl 5.10.1+" />
+<a href="https://travis-ci.org/Csson/p5-MooseX-AttributeDocumented"><img src="https://api.travis-ci.org/Csson/p5-MooseX-AttributeDocumented.svg?branch=master" alt="Travis status" /></a>
+<a href="http://cpants.cpanauthors.org/release/CSSON/MooseX-AttributeDocumented-0.1004"><img src="http://badgedepot.code301.com/badge/kwalitee/CSSON/MooseX-AttributeDocumented/0.1004" alt="Distribution kwalitee" /></a>
+<a href="http://matrix.cpantesters.org/?dist=MooseX-AttributeDocumented%200.1004"><img src="http://badgedepot.code301.com/badge/cpantesters/MooseX-AttributeDocumented/0.1004" alt="CPAN Testers result" /></a>
+<img src="https://img.shields.io/badge/coverage-100.0%-brightgreen.svg" alt="coverage 100.0%" />
+</p>
+
+=end html
+
 =head1 VERSION
 
-Version 0.1003, released 2015-01-18.
+Version 0.1004, released 2019-01-30.
 
 =head1 SYNOPSIS
 
@@ -83,7 +98,7 @@ Erik Carlsson <info@code301.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Erik Carlsson <info@code301.com>.
+This software is copyright (c) 2016 by Erik Carlsson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
